@@ -32,7 +32,7 @@ package Apache2::AMFWURFLFilter;
   # 
 
   use vars qw($VERSION);
-  $VERSION= "3.52";
+  $VERSION= "3.53";
   my $CommonLib = new Apache2::AMFCommonLib ();
  
   my %Capability;
@@ -41,7 +41,6 @@ package Apache2::AMFWURFLFilter;
   my %Array_fullua_id;
   my %Array_DDRcapability;
 
-  my %PatchArray_id;
   my %MobileArray=$CommonLib->getMobileArray;
   my %PCArray=$CommonLib->getPCArray;
   my $mobileversionurl="none";
@@ -51,13 +50,9 @@ package Apache2::AMFWURFLFilter;
   my $resizeimagedirectory="none";
   my $wurflnetdownload="false";
   my $downloadwurflurl="false";
-  my $loadwebpatch="false";
-  my $patchwurflnetdownload="false"; 
-  my $patchwurflurl="";
   my $listall="false";
   my $cookiecachesystem="false";
   my $WURFLVersion="unknown";
-  my $WURFLPatchVersion="unknown";
   my $personalwurflurl='unknown';
   my $cachedirectorystore="/tmp";
   my $capabilitylist="none";
@@ -195,23 +190,6 @@ sub loadConfigFile {
 				      $CommonLib->printLog("AMFMobileKeys is: $ENV{AMFMobileKeys}");
 		} 	
 	             
-	      	 if ($ENV{LoadWebPatch}) {
-				$loadwebpatch=$ENV{LoadWebPatch};
-				$CommonLib->printLog("LoadWebPatch is: $loadwebpatch");
-			 }	
-	      	 if ($ENV{PatchWurflNetDownload}) {
-				if ($ENV{PatchWurflNetDownload} eq 'true' || $ENV{PatchWurflNetDownload} eq 'false') {
-					$patchwurflnetdownload=$ENV{PatchWurflNetDownload};
-					$CommonLib->printLog("PatchWurflNetDownload is: $patchwurflnetdownload");
-				} else {
-					$CommonLib->printLog("Error PatchWurflNetDownload parmeter must set to true or false");					
-					ModPerl::Util::exit();
-				}
-		}	
-	      	 if ($ENV{PatchWurflUrl}) {
-				$patchwurflurl=$ENV{PatchWurflUrl};
-				$CommonLib->printLog("PatchWurflUrl is: $patchwurflurl");
-			 }	
 
 			 if ($ENV{AMFProductionMode}) {
 				$cookiecachesystem=$ENV{AMFProductionMode};
@@ -310,60 +288,6 @@ sub loadConfigFile {
 			}
 		}
 		close IN;
-		#
-		# Start for web_patch_wurfl (full browser)
-		#
-		if ($loadwebpatch eq 'true') {
-			if ($patchwurflnetdownload eq "true") {
-				$CommonLib->printLog("Start downloading patch WURFL from $patchwurflurl");
-			    my ($content_type, $document_length, $modified_time, $expires, $server) = head($patchwurflurl);
-		        if ($content_type eq "") {
-	   		        $CommonLib->printLog("Couldn't get $patchwurflurl.");
-			   		ModPerl::Util::exit();
-		        } else {
-		            $CommonLib->printLog("The URL for download patch WURFL is correct");
-		            $CommonLib->printLog("The size of document is: $document_length bytes");	       
-		        }
-				my $content = get ($patchwurflurl);
-				$CommonLib->printLog("Finish downloading  patch WURFL.xml");
-				if ($content eq "") {
-					$CommonLib->printLog("Couldn't get patch $patchwurflurl.");
-					ModPerl::Util::exit();
-				}
-				$content =~ s/\n//g;
-				$content =~ s/>/>\n/g;
-				my @rows = split(/\n/, $content);
-				my $row;
-				my $count=0;
-				foreach $row (@rows){
-					$r_id=parsePatchFile($row,$r_id);
-				}
-	         } else {
-				my $filePatch="$ENV{AMFMobileHome}/web_browsers_patch.xml";
-				if (-e "$filePatch") {
-						$CommonLib->printLog("Start loading Web Patch File of WURFL");
-						if (open (IN,"$filePatch")) {
-							my $filesize= -s $filePatch;
-							my $string_file;
-							read (IN,$string_file,$filesize);
-							close IN;
-							$string_file =~ s/\n//g;
-							$string_file =~ s/>/>\n/g;
-							my @arrayFile=split(/\n/, $string_file);
-							foreach my $line (@arrayFile) {
-								$r_id=parsePatchFile($line,$r_id);
-							}
-						} else {
-							$CommonLib->printLog("Error open file:$filePatch");
-							ModPerl::Util::exit();
-						}
-				} else {
-				  $CommonLib->printLog("File patch $filePatch not found");
-				  ModPerl::Util::exit();
-				}
-			}
-		}
-		close IN;
 	my $arrLen = scalar %Array_fb;
 	($arrLen,$dummy)= split(/\//, $arrLen);
 	if ($arrLen == 0) {
@@ -372,9 +296,6 @@ sub loadConfigFile {
 		     ModPerl::Util::exit();
 	}
         $CommonLib->printLog("WURFL version: $WURFLVersion");
-	if ($WURFLVersion ne 'unknown'){
-		$CommonLib->printLog("Patch File version: $WURFLPatchVersion");		
-	}
         if ($cacheSystem->restore('wurfl-conf', 'amfver') ne $VERSION||$cacheSystem->restore('wurfl-conf', 'ResizeImageDirectory') ne $resizeimagedirectory||$cacheSystem->restore('wurfl-conf', 'DownloadWurflURL') ne $downloadwurflurl||$cacheSystem->restore('wurfl-conf', 'FullBrowserUrl') ne $fullbrowserurl||$cacheSystem->restore('wurfl-conf', 'RedirectTranscoderUrl') ne $redirecttranscoderurl || $cacheSystem->restore('wurfl-conf', 'ver') ne $WURFLVersion || $cacheSystem->restore('wurfl-conf', 'caplist') ne $capabilitylist||$cacheSystem->restore('wurfl-conf', 'listall') ne $listall) {
             $CommonLib->printLog("********************************************************************************************************");
             $CommonLib->printLog("* This is a new version of WURFL or you change some parameter value or it's a new version of AMF, now the old cache must be deleted *");
@@ -501,53 +422,7 @@ sub parseWURFLFile {
 			}
 		 }
 		 if ($record =~ /\/ver>/o) {
-		     $WURFLVersion=substr($record,index($record,'<ver>') + 5,index($record,'</ver>') - 9);
-		 }
-		 return $id;
-
-}
-sub parsePatchFile {
-         my ($record,$val) = @_;
-		 my $null="";
-		 my $null2="";
-		 my $null3="";
-		 my $ua="";
-		 my $fb="";
-		 my $value="";
-		 my $id;
-		 my $name="";
-		 if ($val) {
-		    $id="$val";
-		 } 
-	     if ($record =~ /\<device/o) {
-	        if (index($record,'user_agent') > -1 ) {
-	           $ua=lc(substr($record,index($record,'user_agent') + 12,index($record,'"',index($record,'user_agent')+ 13)- index($record,'user_agent') - 12));
-	        }	        
-	        if (index($record,'id') > -1 ) {
-	           $id=substr($record,index($record,'id') + 4,index($record,'"',index($record,'id')+ 5)- index($record,'id') - 4);	
-	        }	        
-	        if (index($record,'fall_back') > -1 ) {
-	           $fb=substr($record,index($record,'fall_back') + 11,index($record,'"',index($record,'fall_back')+ 12)- index($record,'fall_back') - 11);	           
-	        }
-	        if (($fb) && ($id)) {	     	   
-					$Array_fb{"$id"}=$fb;
-				 }
-				 if (($ua) && ($id)) {
-			             $PatchArray_id{$ua}=$id;
-			             $Array_id{$ua}=$id;
-				 }				 
-		 }
-		 if ($record =~ /\<capability/o) { 
-			($null,$name,$null2,$value,$null3,$fb)=split(/\"/, $record);
-			if ($listall eq "true") {
-				$Capability{$name}=$name;
-			}
-			if (($id) && ($Capability{$name}) && ($name) && ($value)) {			   
-			   $Array_DDRcapability{"$val|$name"}=$value;
-			}
-		 }
-		 if ($record =~ /\/last_updated>/o) {
-		     $WURFLPatchVersion=substr($record,0,index($record,"</last_updated>"));
+		     $WURFLVersion=substr($record,index($record,'<ver>') + 1,index($record,'</ver>') - 9);
 		 }
 		 return $id;
 
@@ -614,24 +489,15 @@ sub IdentifyPCUAMethod {
   my $id_find="";
   my $pair;
   my $length=0;
-
   foreach $pair (sort keys %PCArray) {
 	if ($UserAgent =~ m/$pair/) {
-		$id_find=$PCArray{$pair};
+                        $id_find=$PCArray{$pair};
 	}
   }
-  if ($id_find) {}else{$id_find="";};
-  if ($id_find eq "") { 
-	foreach $pair (%PatchArray_id)
-	{
-	     my $value=index($UserAgent,$pair);
-	     
-	     if (index($UserAgent,$pair) > -1) {
-		      if ($PatchArray_id{$pair}) {
-			$id_find=$PatchArray_id{$pair};
-		      }
-	     }
-	}
+  if ($id_find eq "") {
+	if ($UserAgent =~ m/safari/) {
+		$id_find='safari';
+	}      
   }
   return $id_find;
 }
@@ -739,8 +605,8 @@ sub handler {
 					my $pair;
 					my $lcuser_agent=lc($user_agent);
 	  			    if ($mobile==0) {
-						foreach $pair (%MobileArray) {		
-							if ($user_agent =~ m/$pair/i) {
+				   		foreach $pair (%MobileArray) {		
+				    			if ($user_agent =~ m/$pair/i) {
 								$mobile=1;
 							}
 						}
@@ -748,7 +614,7 @@ sub handler {
 							$user_agent=$CommonLib->botDetection($user_agent);    
 							$id=IdentifyPCUAMethod($user_agent);
 						} 
-					}
+				    }
 					if (!$id) {$id="";};
 					if ($id eq "") { 
 						$id=IdentifyUAMethod($user_agent);
@@ -830,7 +696,6 @@ sub handler {
 	$f->subprocess_env("AMF_DEVICE_IS_MOBILE" => $amf_device_ismobile);
 	$f->subprocess_env("AMF_VER" => $VERSION);
 	$f->subprocess_env("AMF_WURFLVER" => $WURFLVersion);
-	$f->subprocess_env("AMF_PATCHFILEVER" => $WURFLPatchVersion);
 	$f->headers_out->set("AMF-Ver"=> $VERSION);
 	if ($x_operamini_ua) {
 	    $f->subprocess_env("AMF_MOBILE_BROWSER" => $x_operamini_ua);
